@@ -1,16 +1,6 @@
-
-"""SCons.Tool.qt
-
-Tool-specific initialization for Qt.
-
-There normally shouldn't be any need to import this module directly.
-It will usually be imported through the generic SCons.Tool.Tool()
-selection method.
-
-"""
-
+# MIT License
 #
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,14 +20,16 @@ selection method.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
-from __future__ import print_function
 
-__revision__ = "/src/script/src/engine/SCons/Tool/qt.py none 2019-12-16 19:06:27 none"
+"""Tool-specific initialization for Qt.
+
+There normally shouldn't be any need to import this module directly.
+It will usually be imported through the generic SCons.Tool.Tool()
+selection method.
+"""
 
 import os.path
 import re
-import glob
 
 import SCons.Action
 import SCons.Builder
@@ -48,7 +40,7 @@ import SCons.Util
 import SCons.Tool.cxx
 cplusplus = SCons.Tool.cxx
 
-class ToolQtWarning(SCons.Warnings.Warning):
+class ToolQtWarning(SCons.Warnings.SConsWarning):
     pass
 
 class GeneratedMocFileNotIncluded(ToolQtWarning):
@@ -117,7 +109,7 @@ def find_file(filename, paths, node_factory):
             return node
     return None
 
-class _Automoc(object):
+class _Automoc:
     """
     Callable class, which works as an emitter for Programs, SharedLibraries and
     StaticLibraries.
