@@ -1,7 +1,7 @@
-__version__="4.1.0"
+__version__="4.2.0"
 __copyright__="Copyright (c) 2001 - 2021 The SCons Foundation"
 __developer__="_reproducible"
-__date__="2021-07-21 01:11:56"
+__date__="Tue, 03 Aug 2021 00:25:45 +0000"
 __buildsys__="_reproducible"
 __revision__=""
 __build__=""
